==> calendar-v1.7.21.zip: calendar/messages/pt-BR/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Adicionar</strong> calendário de perfil',
    '<strong>Choose</strong> target calendar' => '<strong>Escolha</strong> o calendário de destino',
    '<strong>Reminder</strong> settings' => 'Configurações de <strong>Lembrete</strong>',
    'Add all Space members with status {status}' => 'Adicione todos os membros do Space com status {status}',
    'Add participants...' => 'Adicione participantes...',
    'Added: {users}' => 'Adicionado: {users}',
    'Additional Information for participants' => 'Informações adicionais para participantes',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Adicione um calendário para eventos privados ou públicos em seu perfil e menu principal.',
    'Adds an event calendar to this space.' => 'Adicione um evento para este espaço.',
    'After (occurrences)' => 'Depois de (ocorrências)',
    'All Day' => 'Todo dia',
    'Allow option \'Decline\'' => 'Permitir opção \'Recusar\'',
    'Allow option \'Undecided\'' => 'Permitir opção \'Indeciso\'',
    'Allows the user to create new calendar entries' => 'Permitir que usuários criem novas entradas de calendário',
    'Allows the user to edit/delete existing calendar entries' => 'Permitir que usuários alterem/apaguem entradas de calendário existentes',
    'Attending' => 'Participando',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => 'Antes que um calendário de destino possa ser selecionado, o módulo deve ser ativado em pelo menos um Espaço.',
    'Birthday' => 'Aniversário',
    'CalDAV' => 'CalDAV',
    'Calendar' => 'Calendário',
    'Calendar event' => 'Evento do calendário',
    'Calendar event content ID' => 'ID do conteúdo do evento do calendário',
    'Calendar events' => 'Eventos do calendário',
    'Cancel Event' => 'Cancelar evento',
    'Cannot remove the participant!' => 'Não é possível remover o participante!',
    'Create entry' => 'Criar entrada',
    'Custom reminder' => 'Lembrete personalizado',
    'Day' => 'Dia',
    'Days' => 'Dias',
    'Default reminder settings' => 'Configurações de lembrete padrão',
    'Delete all events' => 'Apagar todos os eventos',
    'Deleted' => 'Apagado',
    'Description' => 'Descrição',
    'Display events within the next X days' => 'Exibir eventos nos próximos X dias',
    'Do you want to install this module on your profile?' => 'Quer instalar este módulo em seu perfil?',
    'Download ICS' => 'Baixar ICS',
    'Edit' => 'Editar',
    'Edit Event' => 'Editar evento',
    'Edit all events' => 'Editar todos os eventos',
    'Edit this and following events' => 'Edite este e os eventos seguintes',
    'Edit this event' => 'Editar esse evento',
    'Email' => 'E-mail',
    'Enable' => 'Habilitar',
    'Enable Reminder' => 'Ativar Lembrete',
    'End' => 'Fim',
    'End Date' => 'Data Final',
    'End Time' => 'Hora de término',
    'End time must be after start time!' => 'A hora de término precisa ser depois da hora de início!',
    'Event' => 'Evento',
    'Event Type' => 'Tipo de Evento',
    'Event Types' => 'Tipos de Eventos',
    'Event could not be deleted!' => 'O evento não pôde ser excluído!',
    'Event has been be deleted!' => 'O evento foi excluído!',
    'Event not found!' => 'Evento não encontrado!',
    'Export as {type}' => 'Exportar como {type}',
    'Files' => 'Arquivos',
    'Filter by types' => 'Filtrar por tipos',
    'Friday' => 'Sexta-feira',
    'From Newest to Oldest' => 'Do mais novo ao mais antigo',
    'From Oldest to Newest' => 'Do mais antigo ao mais novo',
    'Here you can configure default settings for all calendar events.' => 'Aqui você pode definir as configurações padrão para todos os eventos do calendário.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Aqui você pode configurar lembretes padrão globais. Essas configurações podem ser substituídas no nível de espaço / perfil.',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
        <strong>Set reminder</strong> link.' => 'Aqui você pode definir as configurações de lembrete padrão para este evento. Os usuários podem substituir essas configurações por meio do link <strong> Definir lembrete </strong>.',
    'Hour' => 'Hora',
    'I\'m attending' => 'Estou participando',
    'ID' => 'ID',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'Para adicionar eventos ao seu perfil, você precisa habilitar o módulo de calendário primeiro.',
    'Include Organizer and Participant Info in Exports' => 'Incluir informações do organizador e do participante nas exportações',
    'Interested' => 'Interessado',
    'Invalid date or time format!' => 'Formato de data ou hora inválido!',
    'Invalid day of month given' => 'Dia do mês inválido fornecido',
    'Invalid event type id selected.' => 'Tipo de evento selecionado é inválido',
    'Invalid frequency given' => 'Frequência inválida fornecida',
    'Invalid interval given' => 'Intervalo inválido fornecido',
    'Invalid week day selection' => 'Seleção de dia da semana inválida',
    'Invite' => 'Convidar',
    'Invited: {users}' => 'Convidados: {users}',
    'JWT Key' => 'Chave JWT',
    'JWT Token Expiration' => 'Expiração do Token JWT',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => 'Deixe em branco para listar todos os eventos. Digite 0 para exibir apenas os eventos de hoje.',
    'List' => 'Lista',
    'Location' => 'Localização',
    'Manage entries' => 'Administrar entradas',
    'Maximum number of participants' => 'Número máximo de participantes',
    'Minute' => 'Minuto',
    'Mode' => 'Modo',
    'Monday' => 'Segunda-feira',
    'Month' => 'Mês',
    'Monthly on day {dayOfMonth}' => 'Mensalmente no dia {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Mensalmente na {position} {dayOfWeek}',
    'Months' => 'Meses',
    'Never' => 'Nunca',
    'Next' => 'Próximo',
    'No new participants were added.' => 'Nenhum novo participante foi adicionado.',
    'No new participants were invited.' => 'Nenhum novo participante foi convidado.',
    'No reminder' => 'Sem lembrete',
    'Notify participants about changes' => 'Notifique os participantes sobre as mudanças',
    'On date' => 'Na data',
    'Participant removed.' => 'Participante removido.',
    'Participants' => 'Participantes',
    'Participation Status' => 'Status de participação',
    'Please select new participants.' => 'Selecione novos participantes.',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => 'Eventos privados são visíveis apenas para você e, se o sistema de amizade estiver ativado, para seus amigos.',
    'Profile Calendar' => 'Calendário do perfil',
    'Public' => 'Público',
    'Recurring' => 'Recorrente',
    'Reopen Event' => 'Reabrir evento',
    'Repeat every' => 'Repita a cada',
    'Saturday' => 'Sábado',
    'Select calendar...' => 'Selecione o calendário...',
    'Select space...' => 'Selecione o usuário...',
    'Set reminder' => 'Definir lembrete',
    'Show past events' => 'Mostrar eventos passados',
    'Sorting' => 'Classificação',
    'Start Date' => 'Data de Inicio',
    'Start Time' => 'Hora de início',
    'Status cannot be updated.' => 'O status não pode ser atualizado.',
    'Status updated.' => 'Status atualizado.',
    'Sunday' => 'Domingo',
    'The event has already ended.' => 'O evento já terminou.',
    'This event does not support recurrent events' => 'Este evento não suporta eventos recorrentes',
    'Thursday' => 'Quinta-feira',
    'Time Zone' => 'Fuso Horário',
    'Title' => 'Título',
    'Today' => 'Hoje',
    'Tuesday' => 'Terça-feira',
    'Upcoming {type}' => 'Próximo {type}',
    'Upcoming {type}: {title}' => 'Próximo {type}: {title}',
    'Use default reminder' => 'Usar lembrete padrão',
    'User birthdays' => 'Aniversários do usuário',
    'Wednesday' => 'Quarta-feira',
    'Week' => 'Semana',
    'Weeks' => 'Semanas',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => 'Quando ativada, a exportação de calendários (ics, iCal, CalDAV) incluirá os nomes e endereços de e-mail do organizador e dos participantes. Desative para excluir essas informações e aumentar a privacidade.',
    'Year' => 'Ano',
    'Years' => 'Anos',
    'You cannot invite participants!' => 'Você não pode convidar participantes!',
    'You don\'t have permission to delete this event!' => 'Você não tem permissão para excluir este evento!',
    'You have an <strong>{type}</strong> coming up' => 'Você tem um <strong> {type} </strong> chegando',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Você tem um <strong> {type} </strong> chegando: {title}',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => 'Você foi registrado para o evento "{contentTitle}" em {spaceName}, começando em {time}',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => 'Você foi registrado para o evento "{contentTitle}", que começa em {time}.',
    'You have been registered for the event "{contentTitle}".' => 'Você foi registrado para o evento "{contentTitle}".',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Suas configurações de lembrete para o evento: <strong> \'{title}\' </strong>',
    'canceled' => 'cancelado',
    'disabled' => 'Desativado',
    'first' => 'primeiro',
    'forth' => 'para frente',
    'global' => 'global',
    'iCal' => 'iCal',
    'in seconds. 0 for no JWT token expiration.' => 'em segundos. 0 para nenhuma expiração de token JWT.',
    'last' => 'último',
    'on weekdays' => 'nos dias úteis',
    'second' => 'segundo',
    'third' => 'terceiro',
    '{displayName} Birthday' => 'Aniversário de {displayName}',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} acabou de adicionar você ao evento "{contentTitle}" no espaço {spaceName} a partir de {time}.',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} acabou de adicionar você ao evento "{contentTitle}".',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} acabou de convidar você para o evento "{contentTitle}" no Espaço {spaceName} a partir de {time}.',
    '{displayName} invited you to the event "{contentTitle}".' => '{displayName} acaba de convidar você para o evento "{contentTitle}".',
    '{name} Calendar' => 'Calendário {name}',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
];

==> calendar-v1.8.4.zip: calendar/messages/pt-BR/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Adicionar</strong> calendário de perfil',
    '<strong>Choose</strong> target calendar' => '<strong>Escolha</strong> o calendário de destino',
    '<strong>Reminder</strong> settings' => 'Configurações de <strong>Lembrete</strong>',
    'Add all Space members with status {status}' => 'Adicione todos os membros do Space com status {status}',
    'Add participants...' => 'Adicione participantes...',
    'Added: {users}' => 'Adicionado: {users}',
    'Additional Information for participants' => 'Informações adicionais para participantes',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Adicione um calendário para eventos privados ou públicos em seu perfil e menu principal.',
    'Adds an event calendar to this space.' => 'Adicione um evento para este espaço.',
    'After (occurrences)' => 'Depois de (ocorrências)',
    'All Day' => 'Todo dia',
    'Allow option \'Decline\'' => 'Permitir opção \'Recusar\'',
    'Allow option \'Undecided\'' => 'Permitir opção \'Indeciso\'',
    'Allows the user to create new calendar entries' => 'Permitir que usuários criem novas entradas de calendário',
    'Allows the user to edit/delete existing calendar entries' => 'Permitir que usuários alterem/apaguem entradas de calendário existentes',
    'Attending' => 'Participando',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => 'Antes que um calendário de destino possa ser selecionado, o módulo deve ser ativado em pelo menos um Espaço.',
    'Birthday' => 'Aniversário',
    'CalDAV' => 'CalDAV',
    'Calendar' => 'Calendário',
    'Calendar event' => 'Evento do calendário',
    'Calendar event content ID' => 'ID do conteúdo do evento do calendário',
    'Calendar events' => 'Eventos do calendário',
    'Cancel Event' => 'Cancelar evento',
    'Cannot remove the participant!' => 'Não é possível remover o participante!',
    'Create entry' => 'Criar entrada',
    'Custom reminder' => 'Lembrete personalizado',
    'Day' => 'Dia',
    'Days' => 'Dias',
    'Default reminder settings' => 'Configurações de lembrete padrão',
    'Delete all events' => 'Apagar todos os eventos',
    'Deleted' => 'Apagado',
    'Description' => 'Descrição',
    'Display events within the next X days' => 'Exibir eventos nos próximos X dias',
    'Do you want to install this module on your profile?' => 'Quer instalar este módulo em seu perfil?',
    'Download ICS' => 'Baixar ICS',
    'Edit' => 'Editar',
    'Edit Event' => 'Editar evento',
    'Edit all events' => 'Editar todos os eventos',
    'Edit this and following events' => 'Edite este e os eventos seguintes',
    'Edit this event' => 'Editar esse evento',
    'Email' => 'E-mail',
    'Enable' => 'Habilitar',
    'Enable Reminder' => 'Ativar Lembrete',
    'End' => 'Fim',
    'End Date' => 'Data Final',
    'End Time' => 'Hora de término',
    'End time must be after start time!' => 'A hora de término precisa ser depois da hora de início!',
    'Event' => 'Evento',
    'Event Type' => 'Tipo de Evento',
    'Event Types' => 'Tipos de Eventos',
    'Event could not be deleted!' => 'O evento não pôde ser excluído!',
    'Event has been be deleted!' => 'O evento foi excluído!',
    'Event not found!' => 'Evento não encontrado!',
    'Export as {type}' => 'Exportar como {type}',
    'Files' => 'Arquivos',
    'Filter by types' => 'Filtrar por tipos',
    'Friday' => 'Sexta-feira',
    'From Newest to Oldest' => 'Do mais novo ao mais antigo',
    'From Oldest to Newest' => 'Do mais antigo ao mais novo',
    'Here you can configure default settings for all calendar events.' => 'Aqui você pode definir as configurações padrão para todos os eventos do calendário.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Aqui você pode configurar lembretes padrão globais. Essas configurações podem ser substituídas no nível de espaço / perfil.',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
    <strong>Set reminder</strong> link.' => 'Aqui você pode configurar as configurações de lembrete padrão para este evento. Os usuários podem substituir essas configurações por meio do link <strong>Definir lembrete</strong>.',
    'Hour' => 'Hora',
    'I\'m attending' => 'Estou participando',
    'ID' => 'ID',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'Para adicionar eventos ao seu perfil, você precisa habilitar o módulo de calendário primeiro.',
    'Include Organizer and Participant Info in Exports' => 'Incluir informações do organizador e do participante nas exportações',
    'Interested' => 'Interessado',
    'Invalid date or time format!' => 'Formato de data ou hora inválido!',
    'Invalid day of month given' => 'Dia do mês inválido fornecido',
    'Invalid event type id selected.' => 'Tipo de evento selecionado é inválido',
    'Invalid frequency given' => 'Frequência inválida fornecida',
    'Invalid interval given' => 'Intervalo inválido fornecido',
    'Invalid week day selection' => 'Seleção de dia da semana inválida',
    'Invite' => 'Convidar',
    'Invited: {users}' => 'Convidados: {users}',
    'JWT Key' => 'Chave JWT',
    'JWT Token Expiration' => 'Expiração do Token JWT',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => 'Deixe em branco para listar todos os eventos. Digite 0 para exibir apenas os eventos de hoje.',
    'List' => 'Lista',
    'Location' => 'Localização',
    'Manage entries' => 'Administrar entradas',
    'Maximum number of participants' => 'Número máximo de participantes',
    'Minute' => 'Minuto',
    'Mode' => 'Modo',
    'Monday' => 'Segunda-feira',
    'Month' => 'Mês',
    'Monthly on day {dayOfMonth}' => 'Mensalmente no dia {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Mensalmente na {position} {dayOfWeek}',
    'Months' => 'Meses',
    'Never' => 'Nunca',
    'Next' => 'Próximo',
    'No new participants were added.' => 'Nenhum novo participante foi adicionado.',
    'No new participants were invited.' => 'Nenhum novo participante foi convidado.',
    'No reminder' => 'Sem lembrete',
    'Notify participants about changes' => 'Notifique os participantes sobre as mudanças',
    'On date' => 'Na data',
    'Participant removed.' => 'Participante removido.',
    'Participants' => 'Participantes',
    'Participation Status' => 'Status de participação',
    'Please select new participants.' => 'Selecione novos participantes.',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => 'Eventos privados são visíveis apenas para você e, se o sistema de amizade estiver ativado, para seus amigos.',
    'Profile Calendar' => 'Calendário do perfil',
    'Public' => 'Público',
    'Recurring' => 'Recorrente',
    'Reopen Event' => 'Reabrir evento',
    'Repeat every' => 'Repita a cada',
    'Saturday' => 'Sábado',
    'Select calendar...' => 'Selecione o calendário...',
    'Select space...' => 'Selecione o usuário...',
    'Set reminder' => 'Definir lembrete',
    'Show past events' => 'Mostrar eventos passados',
    'Sorting' => 'Classificação',
    'Start Date' => 'Data de Inicio',
    'Start Time' => 'Hora de início',
    'Status cannot be updated.' => 'O status não pode ser atualizado.',
    'Status updated.' => 'Status atualizado.',
    'Sunday' => 'Domingo',
    'The event has already ended.' => 'O evento já terminou.',
    'This event does not support recurrent events' => 'Este evento não suporta eventos recorrentes',
    'Thursday' => 'Quinta-feira',
    'Time Zone' => 'Fuso Horário',
    'Title' => 'Título',
    'Today' => 'Hoje',
    'Tuesday' => 'Terça-feira',
    'Upcoming {type}' => 'Próximo {type}',
    'Upcoming {type}: {title}' => 'Próximo {type}: {title}',
    'Use default reminder' => 'Usar lembrete padrão',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => 'Usado para geração segura de URLs de feeds do iCal e autenticação CalDAV. Alterar esta chave revogará todos os URLs do iCal e logins CalDAV existentes. Se estiver vazia, uma chave aleatória será gerada automaticamente.',
    'User birthdays' => 'Aniversários do usuário',
    'Wednesday' => 'Quarta-feira',
    'Week' => 'Semana',
    'Weeks' => 'Semanas',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => 'Quando ativada, a exportação de calendários (ics, iCal, CalDAV) incluirá os nomes e endereços de e-mail do organizador e dos participantes. Desative para excluir essas informações e aumentar a privacidade.',
    'Year' => 'Ano',
    'Years' => 'Anos',
    'You cannot invite participants!' => 'Você não pode convidar participantes!',
    'You don\'t have permission to delete this event!' => 'Você não tem permissão para excluir este evento!',
    'You have an <strong>{type}</strong> coming up' => 'Você tem um <strong> {type} </strong> chegando',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Você tem um <strong> {type} </strong> chegando: {title}',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => 'Você foi registrado para o evento "{contentTitle}" em {spaceName}, começando em {time}',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => 'Você foi registrado para o evento "{contentTitle}", que começa em {time}.',
    'You have been registered for the event "{contentTitle}".' => 'Você foi registrado para o evento "{contentTitle}".',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Suas configurações de lembrete para o evento: <strong> \'{title}\' </strong>',
    'canceled' => 'cancelado',
    'disabled' => 'Desativado',
    'first' => 'primeiro',
    'forth' => 'para frente',
    'global' => 'global',
    'iCal' => 'iCal',
    'in seconds. 0 for no JWT token expiration.' => 'em segundos. 0 para nenhuma expiração de token JWT.',
    'last' => 'último',
    'on weekdays' => 'nos dias úteis',
    'second' => 'segundo',
    'third' => 'terceiro',
    '{displayName} Birthday' => 'Aniversário de {displayName}',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} acabou de adicionar você ao evento "{contentTitle}" no espaço {spaceName} a partir de {time}.',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} acabou de adicionar você ao evento "{contentTitle}".',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} acabou de convidar você para o evento "{contentTitle}" no Espaço {spaceName} a partir de {time}.',
    '{displayName} invited you to the event "{contentTitle}".' => '{displayName} acaba de convidar você para o evento "{contentTitle}".',
    '{name} Calendar' => 'Calendário {name}',
    'Filter' => '',
];
